@@ -32,7 +32,7 @@ class WhenTestingPyWebHdfsConstructor(unittest.TestCase):
         self.assertEqual(user_name, webhdfs.user_name)
 
     def test_init_path_to_hosts_provided(self):
-        path_to_hosts = [('.*', ['localhost'])]
+        path_to_hosts = {'.*': ['localhost']}
         webhdfs = PyWebHdfsClient(path_to_hosts=path_to_hosts)
         self.assertIsNotNone(webhdfs.path_to_hosts)
 
@@ -85,7 +85,7 @@ class WhenTestingCreateOperation(unittest.TestCase):
         result = webhdfs.create_file(self.path, self.file_data)
         self.assertTrue(result)
         mock_put.assert_called_with(
-            self.location, headers=self.expected_headers, data=self.file_data)
+            self.location, headers=self.expected_headers, data=self.file_data, timeout=120)
 
 
 class WhenTestingAppendOperation(unittest.TestCase):
@@ -667,7 +667,7 @@ class WhenTestingCreateUri(unittest.TestCase):
 
     def test_create_uri_no_kwargs(self):
         op = operations.CREATE
-        uri = 'http://{{host}}:{port}/webhdfs/v1/' \
+        uri = 'http://{{host}}:{{port}}/webhdfs/v1/' \
               '{path}?op={op}&user.name={user}'\
               .format(port=self.port, path=self.path,
                       op=op, user=self.user_name)
@@ -678,7 +678,7 @@ class WhenTestingCreateUri(unittest.TestCase):
         op = operations.CREATE
         mykey = 'mykey'
         myval = 'myval'
-        uri = 'http://{{host}}:{port}/webhdfs/v1/' \
+        uri = 'http://{{host}}:{{port}}/webhdfs/v1/' \
               '{path}?op={op}&{key}={val}' \
               '&user.name={user}' \
               .format(
@@ -700,7 +700,7 @@ class WhenTestingCreateUri(unittest.TestCase):
         myval = 'myval'
         path = u'die/Stra\xdfe'
         quoted_path = 'die/Stra%C3%9Fe'
-        uri = 'http://{{host}}:{port}/webhdfs/v1/' \
+        uri = 'http://{{host}}:{{port}}/webhdfs/v1/' \
               '{path}?op={op}&{key}={val}' \
               '&user.name={user}' \
               .format(
